@@ -225,7 +225,12 @@ mod tests {
         let split_count =
             search_testnet_results_per_node(LogMarker::SplitSuccess.to_string())?.len();
 
+        let desired_elder_count = elder_count();
         println!("Found splits: {:?}", split_count);
+        println!(
+            "Desired elder_count() per section: {:?}",
+            desired_elder_count
+        );
         println!("Promoted to elder so far: {:?}", promoted_to_elder_nodes);
 
         let total_elders = prefix0_prior_elder_nodes
@@ -246,13 +251,13 @@ mod tests {
         );
         println!("Found prefix_1_new_elders: {:?}", prefix1_new_elder_nodes);
 
-        assert!(prefix0_new_elder_nodes + prefix0_prior_elder_nodes >= elder_count());
-        assert!(prefix1_prior_elder_nodes + prefix1_new_elder_nodes >= elder_count());
+        // assert!(prefix0_new_elder_nodes + prefix0_prior_elder_nodes >= desired_elder_count);
+        // assert!(prefix1_prior_elder_nodes + prefix1_new_elder_nodes >= desired_elder_count);
 
-        // we're not discounting demotions at the moment, so just more than 14 is fine
-        assert!(total_elders >= 2 * elder_count());
+        // // we're not discounting demotions at the moment, so just more than 14 is fine
+        // assert!(total_elders >= 2 * desired_elder_count);
 
-        assert!(split_count >= elder_count());
+        assert!(split_count >= desired_elder_count);
 
         Ok(())
     }
