@@ -65,7 +65,7 @@ impl Core {
                 self.network_knowledge().section_key().await,
             )
             .await?;
-        *self.is_dkg_underway.write().await = true;
+
         Ok(commands)
     }
 
@@ -206,8 +206,6 @@ impl Core {
             elder_candidates, failure_set.failed_participants
         );
 
-        *self.is_dkg_underway.write().await = false;
-
         commands.extend(
             self.promote_and_demote_elders_except(&failure_set.failed_participants)
                 .await?,
